@@ -922,7 +922,6 @@ def Robust_Ranking(df,
                    columns,
                    perturbations,
                    weights_array,
-                   index_column,
                    weights_min=0,
                    weights_max= 9999999999,
                    perturbation_range = 0.05,
@@ -941,8 +940,6 @@ def Robust_Ranking(df,
     
     weights_array: an array containing the weights for each column
     
-    index_column: a string specifying the column of alternative
-    
     weights_min: The minimum aceptable value for weights
     
     weights_max: The maximum aceptable value for weights
@@ -974,7 +971,7 @@ def Robust_Ranking(df,
     weight_mean = temp_weights_array.mean()
     perturbation_amount = weight_mean*perturbation_range
             
-    supplier_list = []
+    alter_list = []
     count_column_name = ''
     proportion_column_name = ''
        
@@ -1003,7 +1000,7 @@ def Robust_Ranking(df,
                                                  perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'Weighted Score (Sum)')
             temp_list = temp_df[index_column].values.tolist()
-            supplier_list.append(temp_list)
+            alter_list.append(temp_list)
             
         elif score_type == 'weighted_product':
             count_column_name = 'Weighted Product Count'
@@ -1013,7 +1010,7 @@ def Robust_Ranking(df,
                                                  perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'Weighted Score (Product)')
             temp_list = temp_df[index_column].values.tolist()
-            supplier_list.append(temp_list)
+            alter_list.append(temp_list)
             
         elif score_type == 'topsis':
             count_column_name = 'TOPSIS Count'
@@ -1023,10 +1020,10 @@ def Robust_Ranking(df,
                                            perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'TOPSIS Score')
             temp_list = temp_df[index_column].values.tolist()
-            supplier_list.append(temp_list)
+            alter_list.append(temp_list)
            
     
-    sum_counts = Counter(x for sublist in supplier_list for x in sublist)
+    sum_counts = Counter(x for sublist in alter_list for x in sublist)
     sum_counts = pd.DataFrame.from_dict(sum_counts,orient='index').reset_index()
     sum_counts = sum_counts.rename(columns={'index':index_column,0:count_column_name})
     sum_counts.sort_values(by=count_column_name, ascending=False,inplace=True)
